@@ -137,7 +137,7 @@ debug_dump_cb (const void *pointer, void *data,
     (void) signal;
     (void) type_data;
 
-    if (!signal_data || (string_strcasecmp ((char *)signal_data, "core") == 0))
+    if (!signal_data || (strcmp ((char *)signal_data, PLUGIN_CORE) == 0))
         debug_dump (0);
 
     return WEECHAT_RC_OK;
@@ -175,7 +175,7 @@ debug_sigsegv_cb ()
         "***      then issue command: \"bt full\" and send result to developers.\n"
         "***      See the user's guide for more info about enabling the core files\n"
         "***      and reporting crashes:\n"
-        "***      https://weechat.org/doc/stable/user/#report_crashes\n"
+        "***      https://weechat.org/doc/weechat/stable/user/#report_crashes\n"
         "***\n"
         "***   2. Otherwise send the backtrace (below), only if it is a complete trace.\n"
         "***      Keep the crash log file, just in case developers ask you some info\n"
