@@ -204,8 +204,8 @@ hook_find_pos (struct t_hook *hook)
         {
             if (!ptr_hook->deleted)
             {
-                rc_cmp = string_strcasecmp (HOOK_COMMAND(hook, command),
-                                            HOOK_COMMAND(ptr_hook, command));
+                rc_cmp = string_strcmp (HOOK_COMMAND(hook, command),
+                                        HOOK_COMMAND(ptr_hook, command));
                 if (rc_cmp < 0)
                     return ptr_hook;
                 if ((rc_cmp == 0) && (hook->priority > ptr_hook->priority))
@@ -340,51 +340,6 @@ hook_remove_deleted ()
     }
 }
 
-/*
- * Extracts priority and name from a string.
- *
- * String can be:
- *   - a simple name like "test":
- *       => priority = 1000 (default), name = "test"
- *   - a priority + "|" + name, like "500|test":
- *       => priority = 500, name = "test"
- */
-
-void
-hook_get_priority_and_name (const char *string,
-                            int *priority, const char **name)
-{
-    char *pos, *str_priority, *error;
-    long number;
-
-    if (priority)
-        *priority = HOOK_PRIORITY_DEFAULT;
-    if (name)
-        *name = string;
-
-    if (!string)
-        return;
-
-    pos = strchr (string, '|');
-    if (pos)
-    {
-        str_priority = string_strndup (string, pos - string);
-        if (str_priority)
-        {
-            error = NULL;
-            number = strtol (str_priority, &error, 10);
-            if (error && !error[0])
-            {
-                if (priority)
-                    *priority = number;
-                if (name)
-                    *name = pos + 1;
-            }
-            free (str_priority);
-        }
-    }
-}
-
 /*
  * Initializes a new hook with default values.
  */
@@ -499,13 +454,16 @@ hook_set (struct t_hook *hook, const char *property, const char *value)
     if (!hook_valid (hook))
         return;
 
-    if (string_strcasecmp (property, "subplugin") == 0)
+    if (!property)
+        return;
+
+    if (strcmp (property, "subplugin") == 0)
     {
         if (hook->subplugin)
             free (hook->subplugin);
         hook->subplugin = strdup (value);
     }
-    else if (string_strcasecmp (property, "stdin") == 0)
+    else if (strcmp (property, "stdin") == 0)
     {
         if (!hook->deleted
             && (hook->type == HOOK_TYPE_PROCESS)
@@ -517,7 +475,7 @@ hook_set (struct t_hook *hook, const char *property, const char *value)
             (void) num_written;
         }
     }
-    else if (string_strcasecmp (property, "stdin_close") == 0)
+    else if (strcmp (property, "stdin_close") == 0)
     {
         if (!hook->deleted
             && (hook->type == HOOK_TYPE_PROCESS)
@@ -528,7 +486,7 @@ hook_set (struct t_hook *hook, const char *property, const char *value)
             HOOK_PROCESS(hook, child_write[HOOK_PROCESS_STDIN]) = -1;
         }
     }
-    else if (string_strcasecmp (property, "signal") == 0)
+    else if (strcmp (property, "signal") == 0)
     {
         if (!hook->deleted
             && (hook->type == HOOK_TYPE_PROCESS)
@@ -737,7 +695,7 @@ hook_add_to_infolist_type (struct t_infolist *infolist, int type,
             switch (ptr_hook->type)
             {
                 case HOOK_TYPE_COMMAND:
-                    match = string_match (HOOK_COMMAND(ptr_hook, command), arguments, 0);
+                    match = string_match (HOOK_COMMAND(ptr_hook, command), arguments, 1);
                     break;
                 default:
                     break;
