@@ -21,6 +21,9 @@
 #define WEECHAT_PLUGIN_IRC_CONFIG_H
 
 #define IRC_CONFIG_NAME "irc"
+#define IRC_CONFIG_PRIO_NAME (TO_STR(IRC_PLUGIN_PRIORITY) "|" IRC_CONFIG_NAME)
+
+#define IRC_CONFIG_VERSION 2
 
 enum t_irc_config_look_server_buffer
 {
@@ -107,6 +110,7 @@ extern struct t_config_option *irc_config_look_display_ctcp_unknown;
 extern struct t_config_option *irc_config_look_display_extended_join;
 extern struct t_config_option *irc_config_look_display_host_join;
 extern struct t_config_option *irc_config_look_display_host_join_local;
+extern struct t_config_option *irc_config_look_display_host_notice;
 extern struct t_config_option *irc_config_look_display_host_quit;
 extern struct t_config_option *irc_config_look_display_join_message;
 extern struct t_config_option *irc_config_look_display_old_topic;
